//
//
//    guitune - program for tuning instruments (actually an oscilloscope)
//    Copyright (C) 1999  Florian Berger
//    Email: florian.berger@jk.uni-linz.ac.at
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License Version 2 as
//    published by the Free Software Foundation;
//
//    This program is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with this program; if not, write to the Free Software
//    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
//

#include <qapplication.h>
#include "mainwindow.h"



MainWindow::MainWindow( QWidget *parent, char *name, int argc, char **argv )
    : QMainWindow( parent, name )
{
    mw = new MainWidget( this, "MainWidget", argc, argv );
    setCentralWidget( mw );
    mw->setMinimumSize(380,240);

    filemenu = new QPopupMenu( this,"file_menu" );
    filemenu->setFont( QFont("OldEnglish") );
    filemenu->insertItem( "E&xit", qApp, SLOT( quit() ), ALT+Key_X );
    
    tuningmenu = new QPopupMenu( this,"view_menu" );
    tuningmenu->setFont( QFont("OldEnglish") );
    idm_tuning_norm =
    tuningmenu->insertItem( "&Normal",   this, SLOT( m_tuning_norm() ) );
    idm_tuning_wien =
    tuningmenu->insertItem( "&Wien",     this, SLOT( m_tuning_wien() ) );
    idm_tuning_phys =
    tuningmenu->insertItem( "&Physical", this, SLOT( m_tuning_phys() ) );
    tuningmenu->insertSeparator();
    idm_tuning_equi =
    tuningmenu->insertItem( "&Equidistant", this, SLOT( m_tuning_equi() ) );
    idm_tuning_nat =
    tuningmenu->insertItem( "N&atural",     this, SLOT( m_tuning_nat() ) );
    tuningmenu->setCheckable( TRUE );
    tuningmenu->setItemChecked( idm_tuning_norm, true );
    tuningmenu->setItemChecked( idm_tuning_equi, true );

    scalemenu = new QPopupMenu( this,"view_menu" );
    scalemenu->setFont( QFont("OldEnglish") );
    idm_scale_US =
    scalemenu->insertItem( "&US",           this, SLOT( m_scale_US()  ) );
    idm_scale_USa =
    scalemenu->insertItem( "U&S-Alternate", this, SLOT( m_scale_USa() ) );
    idm_scale_GE =
    scalemenu->insertItem( "&German",       this, SLOT( m_scale_GE()  ) );
    idm_scale_GEa =
    scalemenu->insertItem( "G&erman-Alt.",  this, SLOT( m_scale_GEa() ) );
    scalemenu->setCheckable( TRUE );
    scalemenu->setItemChecked( idm_scale_US, true );
    
    optmenu = new QPopupMenu( this,"options_menu" );
    optmenu->setFont( QFont("OldEnglish") );
    optmenu->insertItem( "&Tuning", tuningmenu );
    optmenu->insertItem( "&Note Scale", scalemenu );
    
    menuBar()->setFont( QFont("OldEnglish") );
    menuBar()->insertItem( "&File", filemenu );
    menuBar()->insertItem( "&Options", optmenu );
}

MainWindow::~MainWindow()
{
}

void MainWindow::resizeEvent(QResizeEvent *)
{
    centralWidget()->resize( width(), height() - menuBar()->height() );
}

void MainWindow::m_tuning_norm()
{
    mw->setTuningNorm();
    tuningmenu->setItemChecked( idm_tuning_norm, true );
    tuningmenu->setItemChecked( idm_tuning_wien, false );
    tuningmenu->setItemChecked( idm_tuning_phys, false );
}
void MainWindow::m_tuning_wien()
{
    mw->setTuningWien();
    tuningmenu->setItemChecked( idm_tuning_norm, false );
    tuningmenu->setItemChecked( idm_tuning_wien, true );
    tuningmenu->setItemChecked( idm_tuning_phys, false );
}
void MainWindow::m_tuning_phys()
{
    mw->setTuningPhys();
    tuningmenu->setItemChecked( idm_tuning_norm, false );
    tuningmenu->setItemChecked( idm_tuning_wien, false );
    tuningmenu->setItemChecked( idm_tuning_phys, true );
}

void MainWindow::m_tuning_equi()
{
    mw->setTuningEqui();
    tuningmenu->setItemChecked( idm_tuning_equi, true  );
    tuningmenu->setItemChecked( idm_tuning_nat,  false );
}
void MainWindow::m_tuning_nat()
{
    mw->setTuningNat();
    tuningmenu->setItemChecked( idm_tuning_equi, false );
    tuningmenu->setItemChecked( idm_tuning_nat,  true  );
}

void MainWindow::m_scale_US()
{
    mw->setScaleUS();
    scalemenu->setItemChecked( idm_scale_US,  true  );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  false  );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void MainWindow::m_scale_USa()
{
    mw->setScaleUSAlt();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, true  );
    scalemenu->setItemChecked( idm_scale_GE,  false );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void MainWindow::m_scale_GE()
{
    mw->setScaleGE();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  true  );
    scalemenu->setItemChecked( idm_scale_GEa, false );
}
void MainWindow::m_scale_GE_a()
{
    mw->setScaleGEAlt();
    scalemenu->setItemChecked( idm_scale_US,  false );
    scalemenu->setItemChecked( idm_scale_USa, false );
    scalemenu->setItemChecked( idm_scale_GE,  false );
    scalemenu->setItemChecked( idm_scale_GEa, true  );
}


/*void MainWindow::paintEvent(QPaintEvent *)
{
}
*/

main(int argc, char *argv[])
{
   QApplication a( argc,argv );
   //   QApplication::setFont( QFont("OldEnglish") );
   MainWindow mainwin( 0, "MainWin", argc, argv );
//   MainWidget   mw(   &mainwin, "MainWidget", argc, argv   );
   //QMainWindow mwin( 0, "MainWindow" );
   //mwin.setCentralWidget( &mw );
   //mw.setGeometry(10,10,500,360);
   a.setMainWidget( &mainwin );
   //mwin.show();
   mainwin.resize(500,281);
   mainwin.show();
   mainwin.resize(500,280);
   return(a.exec());
}
